@@ -6,7 +6,8 @@ SERVER_TYPE <- enum(
 )
 
 format_server_type <- function(field) {
-  enum_case(field,
+  enum_case(
+    field,
     RSC = "RStudio Server Connect",
     SSP = "Shiny Server or Shiny Server Pro",
     SAI = "shinyapps.io",
@@ -34,14 +35,23 @@ servedBy <- function(appUrl) {
   df <- curl::handle_cookies(h)
   headers <- curl::parse_headers_list(resp$headers)
 
-  if (nrow(df[df$name == "SSP-XSRF", ]) == 1 ||
-    isTRUE(headers[["x-powered-by"]] %in% c("Express", "Shiny Server", "Shiny Server Pro"))) {
+  if (
+    nrow(df[df$name == "SSP-XSRF", ]) == 1 ||
+      isTRUE(
+        headers[["x-powered-by"]] %in%
+          c("Express", "Shiny Server", "Shiny Server Pro")
+      )
+  ) {
     return(SERVER_TYPE$SSP)
   } else if (nrow(df[which(df$name == "rscid"), ]) == 1) {
     return(SERVER_TYPE$RSC)
   } else if (hasShinyJs(rawToChar(resp$content))) {
     return(SERVER_TYPE$SHN)
   } else {
-    cli::cli_abort(paste("Target URL", appUrl$build(), "does not appear to be a Shiny application."))
+    cli::cli_abort(paste(
+      "Target URL",
+      appUrl$build(),
+      "does not appear to be a Shiny application."
+    ))
   }
 }
